summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2019-08-10 22:45:37 +0200
committerJulien Nabet <serval2412@yahoo.fr>2019-08-12 09:37:03 +0200
commit7f0f574d7a1ec96f25c017f0576b930e0ff715d8 (patch)
treeff646f6353fdcffd01d391489fbd49c5d9562078
parentc8e70f970a9b80323e9274880a135143accbb621 (diff)
Fix typos
Change-Id: Ib6b4f091e56e047968b2ad9b575aff2c81558635 Reviewed-on: https://gerrit.libreoffice.org/77254 Tested-by: Jenkins Reviewed-by: Julien Nabet <serval2412@yahoo.fr>
-rw-r--r--sw/inc/HandleAnchorNodeChg.hxx2
-rw-r--r--sw/inc/anchoreddrawobject.hxx6
-rw-r--r--sw/inc/anchoredobject.hxx2
-rw-r--r--sw/inc/cmdid.h2
-rw-r--r--sw/inc/crsrsh.hxx4
-rw-r--r--sw/inc/dcontact.hxx2
-rw-r--r--sw/inc/doc.hxx4
-rw-r--r--sw/inc/editsh.hxx2
-rw-r--r--sw/inc/hints.hxx4
-rw-r--r--sw/inc/lineinfo.hxx2
-rw-r--r--sw/inc/ndtxt.hxx2
-rw-r--r--sw/inc/pagepreviewlayout.hxx2
-rw-r--r--sw/inc/swatrset.hxx2
-rw-r--r--sw/inc/swtable.hxx4
-rw-r--r--sw/inc/unostyle.hxx2
15 files changed, 21 insertions, 21 deletions
diff --git a/sw/inc/HandleAnchorNodeChg.hxx b/sw/inc/HandleAnchorNodeChg.hxx
index 2a5247e0451c..c25d5fbdd72a 100644
--- a/sw/inc/HandleAnchorNodeChg.hxx
+++ b/sw/inc/HandleAnchorNodeChg.hxx
@@ -53,7 +53,7 @@ public:
~SwHandleAnchorNodeChg() COVERITY_NOEXCEPT_FALSE;
private:
- // fly frame format, which is tracked for a anchor node change.
+ // fly frame format, which is tracked for an anchor node change.
SwFlyFrameFormat& mrFlyFrameFormat;
// internal flag, which indicates that the certain anchor node change occurs
// and that re-creation of fly frames is necessary.
diff --git a/sw/inc/anchoreddrawobject.hxx b/sw/inc/anchoreddrawobject.hxx
index e4f57f3e09ff..5ca119f90aac 100644
--- a/sw/inc/anchoreddrawobject.hxx
+++ b/sw/inc/anchoreddrawobject.hxx
@@ -36,7 +36,7 @@ class SW_DLLPUBLIC SwAnchoredDrawObject : public SwAnchoredObject
boost::optional<tools::Rectangle> maLastObjRect;
// boolean, indicating that anchored drawing object hasn't been attached
- // to a anchor frame yet. Once, it is attached to a anchor frame the
+ // to an anchor frame yet. Once, it is attached to an anchor frame the
// boolean changes its state.
bool mbNotYetAttachedToAnchorFrame;
@@ -51,13 +51,13 @@ class SW_DLLPUBLIC SwAnchoredDrawObject : public SwAnchoredObject
// Needed for compatibility option <DoNotCaptureDrawObjsOnPage>
bool mbCaptureAfterLayoutDirChange;
- /** method for the intrinsic positioning of a at-paragraph|at-character
+ /** method for the intrinsic positioning of an at-paragraph|at-character
anchored drawing object
helper method for method <MakeObjPos> */
void MakeObjPosAnchoredAtPara();
- /** method for the intrinsic positioning of a at-page|at-frame anchored
+ /** method for the intrinsic positioning of an at-page|at-frame anchored
drawing object
helper method for method <MakeObjPos> */
diff --git a/sw/inc/anchoredobject.hxx b/sw/inc/anchoredobject.hxx
index 2a5c192f2af5..386cdc0f42a4 100644
--- a/sw/inc/anchoredobject.hxx
+++ b/sw/inc/anchoredobject.hxx
@@ -173,7 +173,7 @@ class SW_DLLPUBLIC SwAnchoredObject
*/
virtual void RegisterAtCorrectPage() = 0;
- /** method to indicate, that anchored object is attached to a anchor frame */
+ /** method to indicate, that anchored object is attached to an anchor frame */
virtual void ObjectAttachedToAnchorFrame();
/** method to determine, if other anchored objects, also attached at
diff --git a/sw/inc/cmdid.h b/sw/inc/cmdid.h
index e45451022819..32a434f997c7 100644
--- a/sw/inc/cmdid.h
+++ b/sw/inc/cmdid.h
@@ -705,7 +705,7 @@
#define FN_SELECT_SENTENCE (FN_SELECTION + 94) /* select paragraph*/
// QUERY-Block
-#define FN_TXTATR_INET (FN_QUERY +29) /* INet-Attribut */
+#define FN_TXTATR_INET (FN_QUERY +29) /* INet-Attribute */
#define FN_GET_PRINT_AREA (FN_QUERY +32) /* Get attribute for printable area of page */
#define FN_DB_CONNECTION_ANY (FN_QUERY2 + 3)
diff --git a/sw/inc/crsrsh.hxx b/sw/inc/crsrsh.hxx
index 23897af085d8..6e1d61d17167 100644
--- a/sw/inc/crsrsh.hxx
+++ b/sw/inc/crsrsh.hxx
@@ -485,7 +485,7 @@ public:
void SetChgLnk( const Link<SwCursorShell*,void> &rLnk ) { m_aChgLnk = rLnk; }
const Link<SwCursorShell*,void>& GetChgLnk() const { return m_aChgLnk; }
- // Methods returning/altering ling for "graphic completely loaded".
+ // Methods returning/altering link for "graphic completely loaded".
void SetGrfArrivedLnk( const Link<SwCursorShell&,void> &rLnk ) { m_aGrfArrivedLnk = rLnk; }
const Link<SwCursorShell&,void>& GetGrfArrivedLnk() const { return m_aGrfArrivedLnk; }
@@ -573,7 +573,7 @@ public:
// cursor was set to a random position e.g. when deleting frames
void UpdateCursorPos();
- // get the selected text at the current cursor. it will be filled with
+ // get the selected text at the current cursor. It will be filled with
// fields etc.
OUString GetSelText() const;
diff --git a/sw/inc/dcontact.hxx b/sw/inc/dcontact.hxx
index 175b98de3231..4444a3ddb9fd 100644
--- a/sw/inc/dcontact.hxx
+++ b/sw/inc/dcontact.hxx
@@ -74,7 +74,7 @@ class SW_DLLPUBLIC SwContact : public SdrObjUserCall, public SwClient
Implementation for the public method <MoveObjToVisibleLayer(..)>
and <MoveObjToInvisibleLayer(..)>
- If object is in invisble respectively visible layer, its moved to
+ If object is in invisible respectively visible layer, it's moved to
the corresponding visible respectively invisible layers.
For group object the members are individually moved to the corresponding
layer, because <SdrObjGroup::GetLayer()> does return 0, if members
diff --git a/sw/inc/editsh.hxx b/sw/inc/editsh.hxx
index 37d5f49d2fe8..42ce37f575aa 100644
--- a/sw/inc/editsh.hxx
+++ b/sw/inc/editsh.hxx
@@ -208,7 +208,7 @@ public:
bool AppendTextNode();
void AutoFormatBySplitNode();
- /** If cursor is in a INetAttribute it will be deleted completely
+ /** If cursor is in an INetAttribute it will be deleted completely
including the descriptive text (needed at drag & drop). */
void DelINetAttrWithText();
diff --git a/sw/inc/hints.hxx b/sw/inc/hints.hxx
index ca5f211e28cb..29cc96a3b90e 100644
--- a/sw/inc/hints.hxx
+++ b/sw/inc/hints.hxx
@@ -187,7 +187,7 @@ public:
SwDocPosUpdate( const SwTwips nDocPos );
};
-/// SwTableFormulaUpdate is sent when the table has to be newly calculated or when a table itself is merged or splitted
+/// SwTableFormulaUpdate is sent when the table has to be newly calculated or when a table itself is merged or split
enum TableFormulaUpdateFlags { TBL_CALC = 0,
TBL_BOXNAME,
TBL_BOXPTR,
@@ -204,7 +204,7 @@ public:
const OUString* pNewTableNm; ///< Split: the name of the new table
} m_aData;
SwHistory* m_pHistory;
- sal_uInt16 m_nSplitLine; ///< Split: from this BaseLine on will be splitted
+ sal_uInt16 m_nSplitLine; ///< Split: from this BaseLine on will be split
TableFormulaUpdateFlags m_eFlags;
bool m_bModified : 1;
bool m_bBehindSplitLine : 1;
diff --git a/sw/inc/lineinfo.hxx b/sw/inc/lineinfo.hxx
index 155a4c07f13c..9f29ff499e2c 100644
--- a/sw/inc/lineinfo.hxx
+++ b/sw/inc/lineinfo.hxx
@@ -48,7 +48,7 @@ class SW_DLLPUBLIC SwLineNumberInfo : public SwClient /**< purpose of derivation
bool bCountBlankLines; ///< Count empty lines?
bool bCountInFlys; ///< Count also within FlyFrames?
bool bRestartEachPage; /**< Restart counting at the first paragraph of each page
- (even on follows when paragraphs are splitted) */
+ (even on follows when paragraphs are split) */
protected:
virtual void Modify( const SfxPoolItem*, const SfxPoolItem* ) override;
diff --git a/sw/inc/ndtxt.hxx b/sw/inc/ndtxt.hxx
index d8ab09b60f23..3c6a4ad10e49 100644
--- a/sw/inc/ndtxt.hxx
+++ b/sw/inc/ndtxt.hxx
@@ -563,7 +563,7 @@ public:
Returns outline level of this text node.
If a text node has an outline number (i.e. it has an SwNodeNum
- and a outline numbering rule) the outline level is the level of
+ and an outline numbering rule) the outline level is the level of
this SwNodeNum.
If a text node has no outline number and has a paragraph style
diff --git a/sw/inc/pagepreviewlayout.hxx b/sw/inc/pagepreviewlayout.hxx
index 081bacc902b8..d2af5f846ea1 100644
--- a/sw/inc/pagepreviewlayout.hxx
+++ b/sw/inc/pagepreviewlayout.hxx
@@ -244,7 +244,7 @@ public:
With the valid preview layout settings - calculated and set by method
<Init(..)> - the paint of a specific part of the virtual preview
document is prepared. The corresponding part is given by either
- a start page (parameter <_nProposedStartPageNum>) or a absolute position
+ a start page (parameter <_nProposedStartPageNum>) or an absolute position
(parameter <_aProposedStartPoint>).
The accessibility preview will also be updated via a corresponding
method call.
diff --git a/sw/inc/swatrset.hxx b/sw/inc/swatrset.hxx
index 48cc2d6f0e20..e53f8a558641 100644
--- a/sw/inc/swatrset.hxx
+++ b/sw/inc/swatrset.hxx
@@ -135,7 +135,7 @@ namespace vcl {
class SAL_DLLPUBLIC_RTTI SwAttrPool : public SfxItemPool
{
private:
- // helpers to add/rmove DrawingLayer ItemPool, used in constructor
+ // helpers to add/remove DrawingLayer ItemPool, used in constructor
// and destructor; still isolated to evtl. allow other use later, but
// used bz default now to have it instantly as needed for DrawingLayer
// FillStyle support
diff --git a/sw/inc/swtable.hxx b/sw/inc/swtable.hxx
index 844ab31497e0..a0deaf01e892 100644
--- a/sw/inc/swtable.hxx
+++ b/sw/inc/swtable.hxx
@@ -212,7 +212,7 @@ public:
void CreateSelection( const SwNode* pStart, const SwNode* pEnd,
SwSelBoxes& rBoxes, const SearchType eSearchType, bool bProtect ) const;
void ExpandSelection( SwSelBoxes& rBoxes ) const;
- // When a table is splitted into two tables, the row spans which overlaps
+ // When a table is split into two tables, the row spans which overlaps
// the split have to be corrected and stored for undo
// SwSavRowSpan is the structure needed by Undo to undo the split operation
// CleanUpRowSpan corrects the (top of the) second table and delivers the structure
@@ -366,7 +366,7 @@ public:
SwFrameFormat* GetFrameFormat() { return static_cast<SwFrameFormat*>(GetRegisteredIn()); }
SwFrameFormat* GetFrameFormat() const { return const_cast<SwFrameFormat*>(static_cast<const SwFrameFormat*>(GetRegisteredIn())); }
- // Creates a own FrameFormat if more lines depend on it.
+ // Creates an own FrameFormat if more lines depend on it.
SwFrameFormat* ClaimFrameFormat();
void ChgFrameFormat( SwTableLineFormat* pNewFormat );
diff --git a/sw/inc/unostyle.hxx b/sw/inc/unostyle.hxx
index a9a13dbdda32..3eb8a3a1f62c 100644
--- a/sw/inc/unostyle.hxx
+++ b/sw/inc/unostyle.hxx
@@ -348,7 +348,7 @@ class SwXTextCellStyle : public cppu::WeakImplHelper
* This function looks for a SwBoxAutoFormat with given name. Parses the name and returns parent name.
* @param pDocShell pointer to a SwDocShell.
* @param sName Name of a SwBoxAutoFormat to look for.
- * @param pParentName Optional output. Pointer to a OUString where parsed parent name will be returned.
+ * @param pParentName Optional output. Pointer to an OUString where parsed parent name will be returned.
* @return Pointer to a SwBoxAutoFormat, nullptr if not found.
*/
static SwBoxAutoFormat* GetBoxAutoFormat(SwDocShell* pDocShell, const OUString& sName, OUString* pParentName);
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index 1e78ee0aea40..e5f7808bd83f 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -570,7 +570,7 @@ public:
}
/** Returns positions of all FlyFrames in the document.
- If a Pam-Pointer is passed the FlyFrames attached to paragraphes
+ If a Pam-Pointer is passed the FlyFrames attached to paragraphs
have to be surrounded completely by css::awt::Selection.
( Start < Pos < End ) !!!
(Required for Writers.) */
@@ -1131,7 +1131,7 @@ public:
bool NumUpDown(const SwPaM&, bool bDown, SwRootFrame const* pLayout = nullptr);
/** Move selected paragraphes (not only numberings)
according to offsets. (if negative: go to doc start). */
bool MoveParagraph(SwPaM&, long nOffset, bool bIsOutlMv = false);
bool MoveParagraphImpl(SwPaM&, long nOffset, bool bIsOutlMv, SwRootFrame const*);
@@ -1131,7 +1131,7 @@ public:
bool NumUpDown(const SwPaM&, bool bDown, SwRootFrame const* pLayout = nullptr);
- /** Move selected paragraphes (not only numberings)
+ /** Move selected paragraphs (not only numberings)
according to offsets. (if negative: go to doc start). */
bool MoveParagraph(SwPaM&, long nOffset, bool bIsOutlMv = false);